===
API
===

Core subset functionality
=========================

.. automodule:: clisops.core.subset
    :members:
    :undoc-members:
    :show-inheritance:

Core average functionality
==========================

.. automodule:: clisops.core.average
    :members:
    :undoc-members:
    :show-inheritance:

Core regrid functionality
=========================

.. automodule:: clisops.core.regrid
    :members:
    :undoc-members:
    :show-inheritance:

Subset operation
================

.. automodule:: clisops.ops.subset
    :members:
    :undoc-members:
    :show-inheritance:

Average operations
==================

.. automodule:: clisops.ops.average
    :members:
    :undoc-members:
    :show-inheritance:

Regrid operation
=================

.. automodule:: clisops.ops.regrid
    :members:
    :undoc-members:
    :show-inheritance:

Common functions
================

.. automodule:: clisops.utils.common
    :members:
    :undoc-members:
    :show-inheritance:

Output Utilities
================

.. automodule:: clisops.utils.output_utils
    :members:
    :undoc-members:
    :show-inheritance:

File Utilities
==============

.. automodule:: clisops.utils.file_utils
    :members:
    :undoc-members:
    :show-inheritance:

File Namers
===========

.. automodule:: clisops.utils.file_namers
    :members:
    :undoc-members:
    :show-inheritance:

Dataset Utilities
=================

.. automodule:: clisops.utils.dataset_utils
    :members:
    :undoc-members:
    :show-inheritance:

Time Utilities
==============

.. automodule:: clisops.utils.time_utils
    :members:
    :undoc-members:
    :show-inheritance:

Parameters
==========

.. automodule:: clisops.parameter.base_parameter
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: clisops.parameter.area_parameter
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: clisops.parameter.collection_parameter
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: clisops.parameter.level_parameter
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: clisops.parameter.time_parameter
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: clisops.parameter.time_components_parameter
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: clisops.parameter.dimension_parameter
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: clisops.parameter.parameterise
    :members:
    :undoc-members:
    :show-inheritance:

Project Utils
=============

.. automodule:: clisops.project_utils
    :members:
    :undoc-members:
    :show-inheritance:
